@@ -18,7 +18,7 @@ sub __get_attr_class {
 use base qw(Google::Ads::AdWords::v201206::AdExtension);
 # Variety: sequence
 use Class::Std::Fast::Storable constructor => 'none';
-use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);
+use base qw(Google::Ads::SOAP::Typelib::ComplexType);
 
 Class::Std::initialize();
 
@@ -124,12 +124,7 @@ methods:
 
 Constructor. The following data structure may be passed to new():
 
- { # Google::Ads::AdWords::v201206::MobileExtension
-   phoneNumber =>  $some_value, # string
-   countryCode =>  $some_value, # string
-   isCallTrackingEnabled =>  $some_value, # boolean
-   isCallOnly =>  $some_value, # boolean
- },
+
 
 
 
